@@ -91,7 +91,8 @@ void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self)
 
 	exitCode = (exitCode >> 8) & 0xff;
 	gchar *buff = g_strdup_printf("[Exit Code = %d Output Size = %d]\n%s", (char)exitCode, l, line);//If command has output we issue a newline after Exit Code
-	gtk_text_buffer_set_text(self->priv->cmdOutputBuffer,buff,strlen(line));
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) to out buffer(l=%d,buff=%s)", self, strlen(buff), buff);
+	gtk_text_buffer_set_text(self->priv->cmdOutputBuffer,buff,strlen(buff));
 	g_free(buff);
 	g_free(line);
 	g_free(c);
@@ -822,6 +823,8 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 	}
 	self->priv->instanceImportOK=FALSE;
 
+	queen_beecon_config_file_housekeeping(self); // Housekeeping!!! How HARD!!!! :)
+
 	while (!timeToGoBack) {
 		self->priv->currentDialog=self->priv->advancedDialog;
 		int dialogRunResponse = gtk_dialog_run (GTK_DIALOG (self->priv->advancedDialog));
