@@ -57,27 +57,18 @@ void queen_beecon_async_sync_exec_out(QueenBeecon *self, const gchar *whoareyou)
     	g_free(self->priv->execAuxOutput);self->priv->execAuxOutput = NULL;
 
     	queen_beecon_update_content_layout (self);
-    	queen_beecon_exec_animation_progress(self, QBW_STOP_PROGRESS_ANIMATION);
 
-    	/* Remove timeout callback */
-    	if (self->priv->timeout_id) {g_source_remove( self->priv->timeout_id );self->priv->timeout_id = 0;}
-
-#ifndef EXEC_VIA_MUTEX
-    	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) RESET execInProgress...",self);
-        self->priv->execInProgress = FALSE; // Reset execInProgress flag ready for next execution
-        self->priv->hotSpotIndex = 0; //Reset Hot Spot Index to other update policy (only clicks on widget change this index)
+    	queen_beecon_exec_progress_animation(self, QBW_PROGRESS_ANIMATION_STOP);
+    	self->priv->hotSpotIndex = 0;
     	self->priv->clicksCount=0;
     	self->priv->clickX = -1;
     	self->priv->clickY = -1;
-#ifndef MONO_HOTSPOT
-#else // MONO_HOTSPOT
-#ifndef OLD_HOTSPOT_INDEX
-        self->priv->subHotSpotIndex = 0; //Reset Hot Spot Index to other update policy (only clicks on widget change this index)
-#endif // OLD_HOTSPOT_INDEX
-#endif // MONO_HOTSPOT
-#else
-        //g_mutex_unlock(self->priv->execInProgressMutex);
-#endif
+    	//self->priv->isFingerTap=FALSE;
+    	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) RESET execInProgress...",self);
+        self->priv->execInProgress = FALSE; // Reset execInProgress flag ready for next execution
+    	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) RESET clickExecInProgress...",self);
+    	self->priv->clickExecInProgress = FALSE;
+    	g_signal_emit_by_name (self, "sig_content_updated", self->priv->cmdExitStatus);
 	}
 }
 
@@ -122,13 +113,6 @@ gboolean queen_beecon_async_execute_cb_out_watch(GIOChannel *channel, GIOConditi
 	return( TRUE );
 }
 
-gboolean queen_beecon_async_execute_cb_timeout(QueenBeecon *self)
-{
-	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) %s", self, G_STRFUNC);
-    queen_beecon_exec_animation_progress(self, QBW_FRAME_PROGRESS_ANIMATION);
-    return( TRUE );
-}
-
 GIOChannel *queen_beecon_async_execute_set_up_io_channel (gint fd, GIOCondition cond, GIOFunc func, QueenBeecon *self)
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) %s", self, G_STRFUNC);
@@ -188,12 +172,6 @@ void queen_beecon_async_execute(gchar *cmd, QueenBeecon *self)
 
     /* Add watch function to catch termination of the process. This function will clean any remnants of process. */
     self->priv->child_watch_id = g_child_watch_add(pid, (GChildWatchFunc)queen_beecon_async_execute_cb_child_watch, self );
-
-	queen_beecon_exec_animation_progress(self, QBW_CUSTOM_PROGRESS_ANIMATION);
-    queen_beecon_exec_animation_progress(self, QBW_START_PROGRESS_ANIMATION);
-
-    ///* Install timeout fnction that will move the progress bar */
-    if (self->priv->qbwOnSight && self->priv->progressAnimationFrames) self->priv->timeout_id = g_timeout_add( self->priv->progressAnimationTimer*QBW_PROGRESS_ANIMATION_FRAMES_TIMER_STEPS_MSECS, (GSourceFunc)queen_beecon_async_execute_cb_timeout, self);
 }
 
 /**
@@ -243,16 +221,10 @@ gchar *queen_beecon_g_command_param_subst(QueenBeecon *self, const gchar *cmd, c
 	r = g_strreplace(x,"$QBW_ID",                    self->priv->qbwDbusId); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_ON_SIGHT",              self->priv->qbwOnSight?"true":"false"); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_IS_CONNECTED",          self->priv->isConnected?"true":"false"); g_free(x); x = r;
+	//r = g_strreplace(x,"$QBW_IS_FINGER_TAP",         self->priv->isFingerTap?"true":"false"); g_free(x); x = r;
 	r = g_strreplace(x,"$QBW_EXEC_REASON",           action); g_free(x); x = r;
 	b = g_strdup_printf("%d", self->priv->hotSpotIndex);
 	r = g_strreplace(x,"$QBW_HOTSPOT_PRESS",         b); g_free(b); b = NULL; g_free(x); x = r;
-#ifndef MONO_HOTSPOT
-#else // MONO_HOTSPOT
-#ifndef OLD_HOTSPOT_INDEX
-	b = g_strdup_printf("%d", self->priv->subHotSpotIndex);
-	r = g_strreplace(x,"$QBW_SUBHOTSPOT_PRESS",      b); g_free(b); b = NULL; g_free(x); x = r;
-#endif // OLD_HOTSPOT_INDEX
-#endif // MONO_HOTSPOT
 	b = g_strdup_printf("%d", self->priv->clickX);
 	r = g_strreplace(x,"$QBW_CLICK_X",               b); g_free(b); b = NULL; g_free(x); x = r;
 	b = g_strdup_printf("%d", self->priv->clickY);
