@@ -20,7 +20,6 @@
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-
 #include <glib.h>
 #include <glib/gprintf.h>
 #include <gtk/gtk.h>
@@ -28,40 +27,64 @@
 #include "queen-beecon.h"
 #include "queen-beecon-progress-animation.h"
 
+#define xANIM_ALIGNMENT
+
 gchar *qbwProgressAnimationAction[] = {
-	"QBW_INIT_PROGRESS_ANIMATION",
-	"QBW_CUSTOM_PROGRESS_ANIMATION",
-	"QBW_START_PROGRESS_ANIMATION",
-	"QBW_STOP_PROGRESS_ANIMATION",
-	"QBW_FRAME_PROGRESS_ANIMATION",
-	"QBW_DEINIT_PROGRESS_ANIMATION",
+	"QBW_PROGRESS_ANIMATION_INIT",
+	"QBW_PROGRESS_ANIMATION_START",
+	"QBW_PROGRESS_ANIMATION_STOP",
+	"QBW_PROGRESS_ANIMATION_FRAME",
+	"QBW_PROGRESS_ANIMATION_DEINIT",
 	NULL
 };
 
-void queen_beecon_exec_animation_progress(QueenBeecon *self, QbwProgressAnimationAction action)
+static gboolean queen_beecon_exec_animation_callback(QueenBeecon *self)
 {
-	if (action!=QBW_FRAME_PROGRESS_ANIMATION) qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) %s action=%s OnSight=%d", self, G_STRFUNC, qbwProgressAnimationAction[action],self->priv->qbwOnSight);
-	guint i;
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) %s", self, G_STRFUNC);
+	queen_beecon_exec_progress_animation(self, QBW_PROGRESS_ANIMATION_FRAME);
+    return( TRUE );
+}
 
-	if (action!=QBW_INIT_PROGRESS_ANIMATION && action!=QBW_STOP_PROGRESS_ANIMATION && !self->priv->progressAnimationFrames) return; // If animation hidden and we are not initializing then we have nothing to do
+void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimationAction action)
+{
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) %s action=%s OnSight=%d animationInProgress=%d", self, G_STRFUNC, qbwProgressAnimationAction[action], self->priv->qbwOnSight, self->priv->animationInProgress);
+	guint i;
 	gchar *progressImgFilename;
+	GdkPixbuf *pixbuf;
+	gint fx,fy,fw,fh;
 
 	switch (action) {
-	case QBW_INIT_PROGRESS_ANIMATION:
-//		for (i=0; i < QBW_PROGRESS_ANIMATION_FRAMES_MAX; i++) {
-			progressImgFilename = g_strdup_printf("%squeen-beecon-progress0.png", SYSTEM_PUBLIC_ICON_DIR);
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) Loading frame pixbuf %s", self, progressImgFilename);
-			self->priv->beeExecuting_pixbuf[0] = gdk_pixbuf_new_from_file(progressImgFilename, NULL);
-			g_free(progressImgFilename);
-//		}
+	case QBW_PROGRESS_ANIMATION_INIT:
+		progressImgFilename = g_strdup_printf("%squeen-beecon-progress0.png", SYSTEM_PUBLIC_ICON_DIR);
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) Loading frame pixbuf %s", self, progressImgFilename);
+		self->priv->beeExecuting_pixbuf[0] = gdk_pixbuf_new_from_file(progressImgFilename, NULL);
+		g_free(progressImgFilename);
 		self->priv->beeExecuting_img = gtk_image_new_from_pixbuf(self->priv->beeExecuting_pixbuf[0]);
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Progress Image %p size[%dx%d]", self, self->priv->beeExecuting_img, (gint)self->priv->widWidth, (gint)self->priv->widHeight);
 		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_img), 1, 1);//(gint)self->priv->widWidth, (gint)self->priv->widHeight);
+#ifndef ANIM_ALIGNMENT
+		self->priv->beeExecuting_fixed = gtk_fixed_new();
+		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_img), gdk_pixbuf_get_width (self->priv->beeExecuting_pixbuf[0]), gdk_pixbuf_get_height (self->priv->beeExecuting_pixbuf[0]));
+		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_fixed), gdk_pixbuf_get_width (self->priv->beeExecuting_pixbuf[0]), gdk_pixbuf_get_height (self->priv->beeExecuting_pixbuf[0]));
+		gtk_table_attach(GTK_TABLE(self->priv->tableLayout), GTK_WIDGET(self->priv->beeExecuting_fixed), 0, 1, 0, 1, GTK_FILL|GTK_EXPAND, GTK_FILL|GTK_EXPAND, 0, 0);
+		gtk_fixed_put (GTK_FIXED (self->priv->beeExecuting_fixed), self->priv->beeExecuting_img, 0, 0);
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) beeExecuting_fixed=%p has_window=%d fixed x=%d y=%d img x=%d y=%d", self, self->priv->beeExecuting_fixed, gtk_fixed_get_has_window(GTK_FIXED (self->priv->beeExecuting_fixed)), self->priv->beeExecuting_fixed->allocation.x, self->priv->beeExecuting_fixed->allocation.y, self->priv->beeExecuting_img->allocation.x, self->priv->beeExecuting_img->allocation.y);
+#else
 		gtk_table_attach(GTK_TABLE(self->priv->tableLayout), GTK_WIDGET(self->priv->beeExecuting_img), 0, 1, 0, 1, GTK_FILL|GTK_EXPAND, GTK_FILL|GTK_EXPAND, 0, 0);
 		gtk_misc_set_alignment(GTK_MISC (self->priv->beeExecuting_img),0.5,0.5);
+#endif
 		break;
-	case QBW_CUSTOM_PROGRESS_ANIMATION:
-		if (!self->priv->qbwOnSight) break; // Is widget On Sight? If no, nonsense to trigger animation
+
+	case QBW_PROGRESS_ANIMATION_START:
+		if (!self->priv->progressAnimationFrames) {
+			self->priv->startupAnimation = FALSE;
+			break; // Is widget On Sight and frames needed? If no, nonsense to trigger animation
+		}
+		if (!self->priv->startupAnimation) if (!self->priv->qbwOnSight) break; // Is widget On Sight and frames needed? If no, nonsense to trigger animation
+		self->priv->startupAnimation = FALSE;
+		self->priv->animationInProgress = TRUE;
+		self->priv->xx=self->priv->clickX;
+		self->priv->yy=self->priv->clickY;
 		for (i=0; i < self->priv->progressAnimationFrames; i++) {
 			gchar *progressCustomImgFilename = NULL;
 			gchar *progressCustomAux1ImgFilename = g_strdup_printf("%s%s%s%d.png", HOME_DIR, QUEEN_BEECON_MYDOCS_IMAGE_DIR, self->priv->progressAnimationBasename, i);
@@ -85,7 +108,7 @@ void queen_beecon_exec_animation_progress(QueenBeecon *self, QbwProgressAnimatio
 			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Custom Progress Image [%s] self->priv->beeExecuting_pixbuf[i]=%p", self, progressCustomImgFilename, self->priv->beeExecuting_pixbuf[i]);
 			if (progressCustomImgFilename!=NULL) {
 				GError *error = NULL;
-				GdkPixbuf *pixbuf = NULL;
+				pixbuf = NULL;
 				qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) Custom Progress Image [%s] loading", self, progressCustomImgFilename);
 				pixbuf = gdk_pixbuf_new_from_file(progressCustomImgFilename, &error);
 				if (!pixbuf) {
@@ -106,29 +129,73 @@ void queen_beecon_exec_animation_progress(QueenBeecon *self, QbwProgressAnimatio
 			g_free(progressCustomAux2ImgFilename);
 		}
 		gtk_image_set_from_pixbuf (GTK_IMAGE(self->priv->beeExecuting_img), self->priv->beeExecuting_pixbuf[0]);
-//		break;
-//	case QBW_START_PROGRESS_ANIMATION:
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) progressAnimationFrames [%d]", self, self->priv->progressAnimationFrames);
-		self->priv->beeExecuting_imgidx=0;
+
+#ifndef ANIM_ALIGNMENT
+		pixbuf = self->priv->beeExecuting_pixbuf[0];
+		fw=gdk_pixbuf_get_width (pixbuf);
+		fh=gdk_pixbuf_get_width (pixbuf);
+		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_img), fw, fh);
+		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_fixed), fw, fh);
+		fx=(self->priv->progressAnimationPos)%3==0?0:(self->priv->progressAnimationPos)%3==1?(gint)self->priv->widWidth/2-fw/2:(gint)self->priv->widWidth-fw;
+		fy=(self->priv->progressAnimationPos)/3==0?0:(self->priv->progressAnimationPos)/3==1?(gint)self->priv->widHeight/2-fh/2:(gint)self->priv->widHeight-fh;
+		if (self->priv->progressAnimationAtClickXY) {
+			if (self->priv->clickX!=-1 && self->priv->clickY!=-1 ) {
+				fx=self->priv->xx-fw/2;
+				fy=self->priv->yy-fh/2;
+			}
+		}
+		gtk_fixed_move(GTK_FIXED (self->priv->beeExecuting_fixed), self->priv->beeExecuting_img, fx, fy);
+#else
 		gtk_misc_set_alignment(GTK_MISC (self->priv->beeExecuting_img),((self->priv->progressAnimationPos)%3)*0.5,((self->priv->progressAnimationPos)/3)*0.5);
+#endif
+
 		gtk_widget_show(self->priv->beeExecuting_img);
-		self->priv->beeExecuting_imgidx++;
+		self->priv->beeExecuting_imgidx=1;
+    	if (self->priv->timeout_id) g_source_remove( self->priv->timeout_id );
+    	self->priv->timeout_id = g_timeout_add( self->priv->progressAnimationTimer*QBW_PROGRESS_ANIMATION_FRAMES_TIMER_STEPS_MSECS, (GSourceFunc)queen_beecon_exec_animation_callback, self);
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) progressAnimationFrames [%d] timeout_id=%d", self, self->priv->progressAnimationFrames, self->priv->timeout_id);
 		break;
-	case QBW_FRAME_PROGRESS_ANIMATION:
+
+	case QBW_PROGRESS_ANIMATION_FRAME:
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) QBW_PROGRESS_ANIMATION_FRAME beeExecuting_imgidx=%d progressAnimationFrames=%d]", self, self->priv->beeExecuting_imgidx, self->priv->progressAnimationFrames);
 		i = self->priv->beeExecuting_imgidx % self->priv->progressAnimationFrames;
-		GdkPixbuf *pixbuf = self->priv->beeExecuting_pixbuf[i];
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) progressAnimationFrame [%d/%d=%p]", self, i, self->priv->progressAnimationFrames, pixbuf);
+		pixbuf = self->priv->beeExecuting_pixbuf[i];
+		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) QBW_PROGRESS_ANIMATION progressAnimationFrame [%d/%d=%p]", self, i, self->priv->progressAnimationFrames, pixbuf);
+#ifndef ANIM_ALIGNMENT
+		fw=gdk_pixbuf_get_width (pixbuf);
+		fh=gdk_pixbuf_get_width (pixbuf);
+		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_img), fw, fh);
+		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_fixed), fw, fh);
+		fx=(self->priv->progressAnimationPos)%3==0?0:(self->priv->progressAnimationPos)%3==1?(gint)self->priv->widWidth/2-fw/2:(gint)self->priv->widWidth-fw;
+		fy=(self->priv->progressAnimationPos)/3==0?0:(self->priv->progressAnimationPos)/3==1?(gint)self->priv->widHeight/2-fh/2:(gint)self->priv->widHeight-fh;
+		if (self->priv->progressAnimationAtClickXY) {
+			if (self->priv->clickX!=-1 && self->priv->clickY!=-1 ) {
+				fx=self->priv->xx-fw/2;
+				fy=self->priv->yy-fh/2;
+			}
+		}
+		gtk_fixed_move(GTK_FIXED (self->priv->beeExecuting_fixed), self->priv->beeExecuting_img, fx, fy);
+#else
+#endif
 		gtk_image_set_from_pixbuf (GTK_IMAGE(self->priv->beeExecuting_img), pixbuf);
 		self->priv->beeExecuting_imgidx++;
 		break;
-	case QBW_STOP_PROGRESS_ANIMATION:
+
+	case QBW_PROGRESS_ANIMATION_STOP:
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) progressAnimationFrames [%d]", self, self->priv->progressAnimationFrames);
-		gtk_widget_hide(self->priv->beeExecuting_img);
+    	/* Remove timeout callback */
+    	if (self->priv->timeout_id) {g_source_remove( self->priv->timeout_id );self->priv->timeout_id = 0;}
+		if (self->priv->animationInProgress) {
+			self->priv->animationInProgress = FALSE;
+			gtk_widget_hide(self->priv->beeExecuting_img);
+		}
 		break;
-	case QBW_DEINIT_PROGRESS_ANIMATION:
+
+	case QBW_PROGRESS_ANIMATION_DEINIT:
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) progressAnimationFrames [%d]", self, self->priv->progressAnimationFrames);
 		for (i=0; i < QBW_PROGRESS_ANIMATION_FRAMES_MAX; i++) if (self->priv->beeExecuting_pixbuf[i] != NULL) g_object_unref (self->priv->beeExecuting_pixbuf[i]);
 		break;
+
 	default:
 		return;
 	}
