@@ -152,6 +152,7 @@ needInstanceSettings:
 		self->priv->widgetVisible = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "widgetVisible", 1);//0=Hidden; 1=Visible
 		self->priv->operationalStatus = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "operationalStatus", 0);//0=Maximized/Enabled
 		self->priv->hideCanvas = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "hideCanvas", FALSE);//FALSE=Show Canvas by default
+		self->priv->hideClickCanvas = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "hideClickCanvas", FALSE);//FALSE=Show Canvas on click by default
 		self->priv->snippetBgRGB = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "snippetBgRGB", 0);//0=Black
 
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) self->priv->snippetExtBgRGB = %p", self, self->priv->snippetExtBgRGB);
@@ -305,6 +306,7 @@ needInstanceSettings:
 		self->priv->progressAnimationFrames = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "progressAnimationFrames", QBW_PROGRESS_ANIMATION_FRAMES_DEFAULT);//QBW_PROGRESS_ANIMATION_FRAMES_DEFAULT=Animation Frames is default (0=Hides animation)
 		self->priv->progressAnimationTimer = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "progressAnimationTimer", QBW_PROGRESS_ANIMATION_FRAMES_TIMER_MSECS/QBW_PROGRESS_ANIMATION_FRAMES_TIMER_STEPS_MSECS);//QBW_PROGRESS_ANIMATION_FRAMES_TIMER_MSECS=Animation Frames timer default
 		self->priv->progressAnimationPos = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "progressAnimationPos", 4);//Animation Position Centered by default
+		self->priv->progressAnimationAtClickXY = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "progressAnimationAtClickXY", FALSE);// Animation at click XY position enabled by default
 
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) self->priv->progressAnimationBasename = %p", self, self->priv->progressAnimationBasename);
 		g_free(self->priv->progressAnimationBasename);self->priv->progressAnimationBasename=NULL;
@@ -379,6 +381,7 @@ void queen_beecon_write_settings (QueenBeecon *self, gboolean needInstanceSettin
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "widgetVisible", self->priv->widgetVisible);//AP3
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "operationalStatus", self->priv->operationalStatus);//AP3
 		g_key_file_set_boolean (keyFile, self->priv->widgetID, "hideCanvas", self->priv->hideCanvas);//FALSE=Show Canvas by default
+		g_key_file_set_boolean (keyFile, self->priv->widgetID, "hideClickCanvas", self->priv->hideClickCanvas);//FALSE=Show Canvas by default
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "snippetBgRGB", self->priv->snippetBgRGB);//AP3
 		g_key_file_set_string (keyFile, self->priv->widgetID, "snippetExtBgRGB", self->priv->snippetExtBgRGB);//AP3
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "beecon_lt0_ImgZoom", self->priv->beecon_lt0_ImgZoom);//AP3
@@ -446,6 +449,7 @@ void queen_beecon_write_settings (QueenBeecon *self, gboolean needInstanceSettin
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "progressAnimationFrames", self->priv->progressAnimationFrames);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "progressAnimationTimer", self->priv->progressAnimationTimer);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "progressAnimationPos", self->priv->progressAnimationPos);
+		g_key_file_set_boolean (keyFile, self->priv->widgetID, "progressAnimationAtClickXY", self->priv->progressAnimationAtClickXY);
 		g_key_file_set_string (keyFile, self->priv->widgetID, "progressAnimationBasename", self->priv->progressAnimationBasename);
 		g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnStartup", self->priv->updOnStartup);
 		g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnClick", self->priv->updOnClick);
